@@ -1,9 +1,9 @@
 package App::vaporcalc::Cmd::Result;
-$App::vaporcalc::Cmd::Result::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [ 'App::vaporcalc::Types' ];
+$App::vaporcalc::Cmd::Result::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -types;
 
-use Moo; use MooX::late;
+use Moo;
 
 has action => (
   lazy      => 1,
@@ -106,7 +106,7 @@ L<App::vaporcalc::Types/"CommandAction">.
 
 =head3 prompt
 
-The prompt to display for L</action> eq 'prompt'
+The prompt to display when L</action> eq 'prompt'
 
 =head3 prompt_callback
 
