@@ -1,19 +1,14 @@
 package App::vaporcalc::Cmd::Subject::Flavor;
-$App::vaporcalc::Cmd::Subject::Flavor::VERSION = '0.005001';
-use Defaults::Modern;
-
+$App::vaporcalc::Cmd::Subject::Flavor::VERSION = '0.005002';
 use App::vaporcalc::Flavor;
 
-use Moo; use MooX::late;
-
-sub _subject { 'flavor' }
+use Defaults::Modern;
+use Moo;
 
+method _subject { 'flavor' }
+method _build_verb { 'show' }
 with 'App::vaporcalc::Role::UI::Cmd';
 
-has '+verb' => (
-  builder => sub { 'show' },
-);
-
 
 method _action_show { $self->_action_view }
 method _action_view {
@@ -105,3 +100,8 @@ method _action_clear {
 }
 
 1;
+
+=for Pod::Coverage .*
+
+=cut
+
