@@ -1,20 +1,16 @@
 package App::vaporcalc::Cmd::Subject::Help;
-$App::vaporcalc::Cmd::Subject::Help::VERSION = '0.005001';
+$App::vaporcalc::Cmd::Subject::Help::VERSION = '0.005002';
 use Defaults::Modern;
+use Moo;
 
-use Moo; use MooX::late;
-
-sub _subject { 'help' }
-
+method _subject { 'help' }
+method _build_verb { 'show' }
 with 'App::vaporcalc::Role::UI::Cmd';
 
 has '+recipe' => (
   isa     => Any,
 );
 
-has '+verb' => (
-  builder => sub { 'show' },
-);
 
 method _action_view { $self->_action_show }
 method _action_show {
@@ -43,3 +39,8 @@ method _action_show {
 }
 
 1;
+
+=for Pod::Coverage .*
+
+=cut
+
