@@ -1,18 +1,14 @@
 package App::vaporcalc::Cmd::Subject::Recipe;
-$App::vaporcalc::Cmd::Subject::Recipe::VERSION = '0.005001';
-use Defaults::Modern;
-
+$App::vaporcalc::Cmd::Subject::Recipe::VERSION = '0.005002';
 use App::vaporcalc::RecipeResultSet;
 
-use Moo; use MooX::late;
-
-sub _subject { 'recipe' }
+use Defaults::Modern;
+use Moo;
 
+method _subject { 'recipe' }
+method _build_verb { 'show' }
 with 'App::vaporcalc::Role::UI::Cmd';
 
-has '+verb' => (
-  builder => sub { 'show' },
-);
 
 method _action_show { $self->_action_view }
 method _action_view {
@@ -45,3 +41,8 @@ method _action_load {
 }
 
 1;
+
+=for Pod::Coverage .*
+
+=cut
+
