@@ -1,17 +1,12 @@
 package App::vaporcalc::Cmd::Subject::Vg;
-$App::vaporcalc::Cmd::Subject::Vg::VERSION = '0.005001';
+$App::vaporcalc::Cmd::Subject::Vg::VERSION = '0.005002';
 use Defaults::Modern;
+use Moo;
 
-use Moo; use MooX::late;
-
-sub _subject { 'vg' }
-
+method _subject { 'vg' }
+method _build_verb { 'show' }
 with 'App::vaporcalc::Role::UI::Cmd';
 
-has '+verb' => (
-  builder => sub { 'show' },
-);
-
 
 method _action_show { $self->_action_view }
 method _action_view {
@@ -35,3 +30,8 @@ method _action_set {
 }
 
 1;
+
+=for Pod::Coverage .*
+
+=cut
+
