@@ -1,8 +1,8 @@
 package App::vaporcalc::Exception;
-$App::vaporcalc::Exception::VERSION = '0.005001';
+$App::vaporcalc::Exception::VERSION = '0.005002';
 use Defaults::Modern;
 
-use Moo; use MooX::late;
+use Moo;
 extends 'Throwable::Error';
 
 1;
