@@ -1,9 +1,9 @@
 package App::vaporcalc::Flavor;
-$App::vaporcalc::Flavor::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [ 'App::vaporcalc::Types' ];
+$App::vaporcalc::Flavor::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -types;
 
-use Moo; use MooX::late;
+use Moo;
 
 has percentage => (
   required  => 1,
