@@ -1,11 +1,9 @@
 package App::vaporcalc::Recipe;
-$App::vaporcalc::Recipe::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [
-    'App::vaporcalc::Types',
-  ];
+$App::vaporcalc::Recipe::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -types;
 
-use Moo; use MooX::late;
+use Moo;
 
 has target_quantity   => (
   required => 1,
