@@ -1,10 +1,10 @@
 package App::vaporcalc::RecipeResultSet;
-$App::vaporcalc::RecipeResultSet::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [ 'App::vaporcalc::Types' ];
+$App::vaporcalc::RecipeResultSet::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -types;
 
 
-use Moo; use MooX::late;
+use Moo;
 
 has recipe => (
   required => 1,
