@@ -1,9 +1,9 @@
 package App::vaporcalc::Result;
-$App::vaporcalc::Result::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [ 'App::vaporcalc::Types' ];
+$App::vaporcalc::Result::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -types;
 
-use Moo; use MooX::late;
+use Moo;
 
  
 has vg => (
