@@ -1,7 +1,7 @@
 package App::vaporcalc::Role::Calc;
-$App::vaporcalc::Role::Calc::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [ 'App::vaporcalc::Types' ];
+$App::vaporcalc::Role::Calc::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -all;
 
 use App::vaporcalc::Result;
 
