@@ -1,13 +1,13 @@
 package App::vaporcalc::Role::UI::Cmd;
-$App::vaporcalc::Role::UI::Cmd::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [ 'App::vaporcalc::Types' ];
+$App::vaporcalc::Role::UI::Cmd::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -types;
 
 use App::vaporcalc::Exception;
 use App::vaporcalc::Recipe;
 use App::vaporcalc::Cmd::Result;
 
-use Moo::Role; use MooX::late;
+use Moo::Role;
 
 has verb => (
   is       => 'ro',
