@@ -1,7 +1,7 @@
 package App::vaporcalc::Role::UI::PrepareCmd;
-$App::vaporcalc::Role::UI::PrepareCmd::VERSION = '0.005001';
-use Defaults::Modern
-  -with_types => [ 'App::vaporcalc::Types' ];
+$App::vaporcalc::Role::UI::PrepareCmd::VERSION = '0.005002';
+use Defaults::Modern;
+use App::vaporcalc::Types -types;
 
 use Module::Runtime 'use_package_optimistically';
 
