@@ -1,6 +1,6 @@
 package App::vaporcalc::Types;
-$App::vaporcalc::Types::VERSION = '0.005001';
-use strict; use warnings FATAL => 'all';
+$App::vaporcalc::Types::VERSION = '0.005002';
+use strictures 2;
 
 use match::simple;
 
